﻿#region Details
// Class  - GameController 
// Author - Chris 230115
// Description:
// Main Game Controller Class
// Contains all other controllers and game elements
// Singleton implementation
#endregion

#region Includes
using UnityEngine;
using System.Collections;
#endregion

// GameController //
public class GameController : MonoBehaviour {
	// Static Instance of Game Controller
	private static GameController sInstance;

	// There can only be one!
	public static GameController Instance {
		get {
			if( !sInstance ) {
				UnityEngine.Object[] tmp_objects = GameObject.FindObjectsOfType( typeof( GameController ) );
				if( tmp_objects.Length <= 0 ) {
					Debug.LogError( "There is no Gameobject for GameController active!" );
				} else if( tmp_objects.Length > 1 ) {
					Debug.LogError( "There is more than one instance of GameController active!" );
				} else {
					sInstance = ( GameController )tmp_objects[ 0 ];
				}
			}
			
			return sInstance;
		}
	}

	// GameState Variables //
	public enum GameState { MENU, PLAYING, END };
	private     GameState mCurrentGameState;

	// Unity Editor Variables //
	[ SerializeField ] private GameObject mIntroAndInstructions = null;
	[ SerializeField ] private GameObject mEndScreen            = null;
	[ SerializeField ] private TextMesh   mScoreTextMesh        = null;
	[ SerializeField ] private int        mGameLength           = 5000;

	// Private Variables //
	private int     mScore       = 0;
	private int     mGameTimer   = 0;

	// Start           //
	// Initialisation! //
	void Start() {
		// Set initial gamestate
		mCurrentGameState = GameState.MENU;
	}

	// Update         //
	// Main Game Loop //
	void Update() {
		// Update Overals and score mesh text renderers
		switch( mCurrentGameState ) {
			case GameState.MENU: {
				mIntroAndInstructions.renderer.enabled = true;
				mEndScreen.renderer.enabled            = false;
				mScoreTextMesh.renderer.enabled        = false;
				break;
			}
			case GameState.PLAYING: {
				mIntroAndInstructions.renderer.enabled = false;
				mEndScreen.renderer.enabled            = false;
				mScoreTextMesh.renderer.enabled        = true;
				mGameTimer++;
				break;
			}
			case GameState.END: {
				mIntroAndInstructions.renderer.enabled = false;
				mEndScreen.renderer.enabled            = true;
				mScoreTextMesh.renderer.enabled        = true;
				mScoreTextMesh.transform.position      = new Vector3( 3.0f, 3.5f, 0.0f );
				break;
			}
		}

		// Update score
		mScoreTextMesh.text = "Score: " + mScore;

		// Push space bar to begin!
		if( Input.GetKeyDown( KeyCode.Space ) ) {
			mCurrentGameState = GameState.PLAYING;
		}

		// Timer and end condition
		if( mGameTimer > mGameLength ) {
			mCurrentGameState = GameState.END;
		}
	}

	// GetState                   //
	// Returns current game state //
	public GameState GetState() {
		return mCurrentGameState;
	}

	// IncreaseScore    //
	// Add to the score //
	public void IncreaseScore( int value ) {
		mScore += value;
	}
}