﻿#region Details
// Class  - Obstacle 
// Author - Chris 230115
// Description:
// Obstacles that player objects can hit
// Three types - first two removable by one of the two players
// Third requires BOTH players to remove
#endregion

#region Includes
using UnityEngine;
using System.Collections;
#endregion

// Obstacle //
public class Obstacle : MonoBehaviour {
	// Obstacle Type //
	public             enum    ObstacleType { WHITE, RED, BLUE, PURPLE };
	[ SerializeField ] private ObstacleType mType = ObstacleType.WHITE;

	// Private Variables //
	private float mMoveDistance = 0.0f;
	private bool  mHasCollided  = false;
	
	// Update                      //
	// Move this object each frame //
	void Update () {
		float distance = 12.0f - mMoveDistance;
		transform.position = new Vector3( distance, transform.position.y, 0.0f );
	}
	
	// OnTriggerEnter2D                                         //
	// Detects if this objects collider enters another collider //
	void OnTriggerEnter2D( Collider2D other ) {
		other.gameObject.GetComponent< Player >().IsDazed();
		mHasCollided = true;
	}
	
	// Move            //
	// Move the object //
	public void Move( float distance ) {
		mMoveDistance += distance;
	}

	// HasBeenHit //
	// Getter     //
	public bool HasBeenHit() {
		if( mHasCollided ) {
			return true;
		} else {
			return false;
		}
	}

	// HasBeenTriggered //
	// Resets flag      //
	public void HasBeenTriggered() {
		mHasCollided = false;
	}

	// GetObstacleType           //
	// Returns the obstacle type //
	public ObstacleType GetObstacleType() {
		return mType;
	}
}